@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.008003;
 
-our $VERSION = '0.113';
+our $VERSION = '0.114';
 use Exporter 'import';
 our @EXPORT_OK = qw( choose_a_directory choose_a_file choose_directories choose_a_number choose_a_subset settings_menu
                      insert_sep get_term_size get_term_width get_term_height unicode_sprintf
@@ -253,7 +253,7 @@ sub _routine_options {
         $options = [ @every, qw( small_first reset thousands_separator ) ];
     }
     elsif ( $caller eq 'choose_a_subset' ) {
-        $options = [ @every, qw( layout order alignment enchanted keep_chosen index prefix all_by_default cs_begin cs_end cs_separator mark busy_string ) ];
+        $options = [ @every, qw( layout order alignment enchanted keep_chosen index prefix all_by_default cs_begin cs_end cs_separator mark busy_string no_spacebar ) ];
     }
     elsif ( $caller eq 'settings_menu' ) {
         $options = [ @every ];
@@ -387,7 +387,7 @@ sub choose_directories {
             my $cs_label_w = print_columns_ext( $self->{cs_label}, $self->{color} );
             $info .= line_fold(
                 $self->{cs_label} . join( ', ', map { decode 'locale_fs', $_ } @$chosen_dirs_fs ), get_term_width(),
-                { subseq_tab => ' ' x $cs_label_w, color => $self->{color} }
+                { subseq_tab => ' ' x $cs_label_w, color => $self->{color}, join => 1 }
             );
             my $prompt = 'Choose directories:' . "\n>" . decode( 'locale_fs', $dir_fs );
             my $bu_opt;
@@ -502,7 +502,7 @@ sub __choose_a_path {
             my $cs_label_w = print_columns_ext( $self->{cs_label}, $self->{color} );
             push @tmp, line_fold(
                 $self->{cs_label} . join( ', ', map { decode 'locale_fs', $_ } @{$opt->{chosen_dirs_fs}} ), get_term_width(),
-                { subseq_tab => ' ' x $cs_label_w, color => $self->{color} }
+                { subseq_tab => ' ' x $cs_label_w, color => $self->{color}, join => 0 }
             );
             my $prompt = defined $self->{prompt} ? $self->{prompt} : 'Browse directories:';
             push @tmp, $prompt . "\n>" . decode( 'locale_fs', $dir_fs );
@@ -797,7 +797,7 @@ sub choose_a_subset {
               meta_items => [ 0 .. $#pre ], mark => $self->{mark}, include_highlighted => 2,
               clear_screen => $self->{clear_screen}, hide_cursor => $self->{hide_cursor},
               color => $self->{color}, tabs_info => $self->{tabs_info}, tabs_prompt => $self->{tabs_prompt},
-              undef => $self->{back}, busy_string => $self->{busy_string} }
+              undef => $self->{back}, busy_string => $self->{busy_string}, no_spacebar => $self->{no_spacebar} }
         );
         $self->{mark} = undef;
         if ( ! defined $idx[0] || $idx[0] == 0 ) {
@@ -963,69 +963,43 @@ sub get_term_height {
 
 
 sub unicode_sprintf {
-    #my ( $unicode, $avail_width, $opt ) = @_;
-    my $opt = defined $_[2] ? $_[2] : {};
+    my ( $str, $avail_w, $opt ) = @_;
+    $opt ||= {};
     my $colwidth;
     if ( $opt->{color} ) {
-        ( my $tmp = $_[0] ) =~ s/\e\[[\d;]*m//msg;
+        ( my $tmp = $str ) =~ s/\e\[[\d;]*m//g;
         $colwidth = print_columns( $tmp );
     }
     else {
-        $colwidth = print_columns( $_[0] );
+        $colwidth = print_columns( $str );
     }
-    if ( $colwidth > $_[1] ) {
-        if ( $opt->{add_dots} ) {
-            return cut_to_printwidth( $_[0], $_[1] - 3 ) . '...';
+    #my $colwidth = print_columns_ext( $str, $opt->{color} );
+    if ( $colwidth > $avail_w ) {
+        if ( @{$opt->{mark_if_truncated}||[]} ) {
+            return cut_to_printwidth( $str, $avail_w - $opt->{mark_if_truncated}[1] ) . $opt->{mark_if_truncated}[0];
         }
-        return cut_to_printwidth( $_[0], $_[1] );
+        return cut_to_printwidth( $str, $avail_w );
     }
-    elsif ( $colwidth < $_[1] ) {
+    elsif ( $colwidth < $avail_w ) {
         if ( $opt->{right_justify} ) {
-            return " " x ( $_[1] - $colwidth ) . $_[0];
+            return " " x ( $avail_w - $colwidth ) . $str;
         }
         else {
-            return $_[0] . " " x ( $_[1] - $colwidth );
+            return $str . " " x ( $avail_w - $colwidth );
         }
     }
     else {
-        return $_[0];
+        return $str;
     }
 }
-#sub unicode_sprintf {
-#    my ( $unicode, $avail_width, $opt ) = @_;
-#    if ( ! defined $opt ) {
-#        $opt = {};
-#    }
-#    my $colwidth = print_columns_ext( $unicode, $opt->{color} );
-#    if ( $colwidth > $avail_width ) {
-#        if ( $opt->{add_dots} ) {
-#            return cut_to_printwidth( $unicode, $avail_width - 3 ) . '...';
-#        }
-#        return cut_to_printwidth( $unicode, $avail_width );
-#    }
-#    elsif ( $colwidth < $avail_width ) {
-#        if ( $opt->{right_justify} ) {
-#            return " " x ( $avail_width - $colwidth ) . $unicode;
-#        }
-#        else {
-#            return $unicode . " " x ( $avail_width - $colwidth );
-#        }
-#    }
-#    else {
-#        return $unicode;
-#    }
-#}
 
 
 sub print_columns_ext {
-    #my ( $str, $color ) = @_;
-    if ( $_[1] ) {
-        ( my $tmp = $_[0] ) =~ s/\e\[[\d;]*m//msg;
-        return print_columns( $tmp );
-    }
-    else {
-        return print_columns( $_[0] );
+    my ( $str, $color ) = @_;
+    if ( $color ) {
+        $str =~ s/\e\[[\d;]*m//g;
     }
+    return print_columns( $str );
 }
 
 
@@ -1045,7 +1019,7 @@ Term::Choose::Util - TUI-related functions for selecting directories, files, num
 
 =head1 VERSION
 
-Version 0.113
+Version 0.114
 
 =cut
 
@@ -1368,6 +1342,8 @@ all_by_default
 
 If enabled, all elements are selected if CONFIRM is chosen without any selected elements.
 
+Values: 0,[1].
+
 =item
 
 alignment
